@@ -146,73 +146,83 @@ class Graph(matplotlib.backends.backend_qt5agg.FigureCanvasQTAgg):
         if flag_ax_2: self.ax_pri_2.axhline(y=0., linewidth=0.5, color="k", linestyle="--")
 
         for np_array in self.numpy_arrays:
-
+            flag_do = True
             n12 = np_array.shape
             if len(n12) == 2:
                 n1, n2 = n12
                 x = np_array[:, 0]
+                flag_do = not(any([numpy.all(numpy.isnan(np_array[:, _i])) for _i in range(n12[1])]))
             elif len(n12) == 1:
                 n1, n2 = n12[0], 1
                 x = np_array[:]
+                flag_do = not(numpy.all(numpy.isnan(x)))
             else:
-                return
+                flag_do = False
+
             if n12[0] == 0:
-                return
+                flag_do = False
 
-            if x_lim_min is not None:
-                x_lim_min = min((numpy.nanmin(x), x_lim_min))
-                x_lim_max = max((numpy.nanmax(x), x_lim_max))
-            else:
-                x_lim_min = numpy.nanmin(x)
-                x_lim_max = numpy.nanmax(x)
-            
-            if n2 == 1:
-                #np_x
-                for _x in x:
-                    self.ax_pri_2.axvline(x=_x, linewidth=0.5, color="k", linestyle=":")
-                #self.ax_pri_2.plot(x, 0*x, "k|", linewidth=1.0)
-            elif n2 == 2:
-                #np_xm
-                y_mod = np_array[:, 1]
-                if y_lim_min is not None:
-                    y_lim_min = min((numpy.nanmin(y_mod), y_lim_min))
-                    y_lim_max = max((numpy.nanmax(y_mod), y_lim_max))
+                
+
+            if flag_do: 
+                if x_lim_min is not None:
+                    x_lim_min = min((numpy.nanmin(x), x_lim_min))
+                    x_lim_max = max((numpy.nanmax(x), x_lim_max))
                 else:
-                    y_lim_min = numpy.nanmin(y_mod)
-                    y_lim_max = numpy.nanmax(y_mod)
+                    x_lim_min = numpy.nanmin(x)
+                    x_lim_max = numpy.nanmax(x)
 
-                self.ax_pri_1.plot(x, y_mod, "k-", linewidth=1.0)
-            elif n2 == 3:
-                #np_xes
-                y_exp = np_array[:, 1]
-                y_sig = np_array[:, 2]
-                if y_lim_min is not None:
-                    y_lim_min = min((numpy.nanmin(y_exp-y_sig), y_lim_min))
-                    y_lim_max = max((numpy.nanmax(y_exp+y_sig), y_lim_max))
-                else:
-                    y_lim_min = numpy.nanmin(y_exp)
-                    y_lim_max = numpy.nanmax(y_exp)
-                self.ax_pri_1.errorbar(x, y_exp, yerr = y_sig, ecolor = col_1,  fmt='.', color=col_1, linewidth = 0.5)
-            elif n2 == 4:
-                #np_xesm
-                y_exp = np_array[:, 1]
-                y_sig = np_array[:, 2]
-                y_mod = np_array[:, 3]
-                if y_lim_min is not None:
-                    y_lim_min = min((numpy.nanmin(y_mod), numpy.nanmin(y_exp-y_sig), y_lim_min))
-                    y_lim_max = max((numpy.nanmax(y_mod), numpy.nanmax(y_exp+y_sig), y_lim_max))
-                else:
-                    y_lim_min = min(numpy.nanmin(y_mod), numpy.nanmin(y_exp-y_sig))
-                    y_lim_max = max(numpy.nanmax(y_mod), numpy.nanmax(y_exp+y_sig))
+                if n2 == 1:
+                    #np_x
+                    for _x in x:
+                        self.ax_pri_2.axvline(x=_x, linewidth=0.5, color="k", linestyle=":")
+                    #self.ax_pri_2.plot(x, 0*x, "k|", linewidth=1.0)
+                elif n2 == 2:
+                    #np_xm
+                    y_mod = np_array[:, 1]
+                    if y_lim_min is not None:
+                        y_lim_min = min((numpy.nanmin(y_mod), y_lim_min))
+                        y_lim_max = max((numpy.nanmax(y_mod), y_lim_max))
+                    else:
+                        y_lim_min = numpy.nanmin(y_mod)
+                        y_lim_max = numpy.nanmax(y_mod)
 
-                y_lim_min_2 = min((numpy.nanmin(y_exp-y_mod), y_lim_min_2))
-                y_lim_max_2 = max((numpy.nanmax(y_exp-y_mod), y_lim_max_2))
+                    self.ax_pri_1.plot(x, y_mod, "k-", linewidth=1.0)
+                elif n2 == 3:
+                    #np_xes
+                    y_exp = np_array[:, 1]
+                    y_sig = np_array[:, 2]
+                    if y_lim_min is not None:
+                        y_lim_min = min((numpy.nanmin(y_exp-y_sig), y_lim_min))
+                        y_lim_max = max((numpy.nanmax(y_exp+y_sig), y_lim_max))
+                    else:
+                        y_lim_min = numpy.nanmin(y_exp)
+                        y_lim_max = numpy.nanmax(y_exp)
+                    self.ax_pri_1.errorbar(x, y_exp, yerr = y_sig, ecolor = col_1,  fmt='.', color=col_1, linewidth = 0.5)
+                elif n2 == 4:
+                    #np_xesm
+                    y_exp = np_array[:, 1]
+                    y_sig = np_array[:, 2]
+                    y_mod = np_array[:, 3]
+                    if y_lim_min is not None:
+                        y_lim_min = min((numpy.nanmin(y_mod), numpy.nanmin(y_exp-y_sig), y_lim_min))
+                        y_lim_max = max((numpy.nanmax(y_mod), numpy.nanmax(y_exp+y_sig), y_lim_max))
+                    else:
+                        y_lim_min = min(numpy.nanmin(y_mod), numpy.nanmin(y_exp-y_sig))
+                        y_lim_max = max(numpy.nanmax(y_mod), numpy.nanmax(y_exp+y_sig))
+
+                    y_lim_min_2 = min((numpy.nanmin(y_exp-y_mod), y_lim_min_2))
+                    y_lim_max_2 = max((numpy.nanmax(y_exp-y_mod), y_lim_max_2))
 
 
-                self.ax_pri_1.errorbar(x, y_exp, yerr = y_sig, ecolor = col_1,  fmt='.', color=col_1, linewidth = 0.5)
-                self.ax_pri_1.plot(x, y_mod, "k-", linewidth=1.0)
-                self.ax_pri_2.plot(x, y_exp-y_mod, "k-", linewidth=1.0)
+                    self.ax_pri_1.errorbar(x, y_exp, yerr = y_sig, ecolor = col_1,  fmt='.', color=col_1, linewidth = 0.5)
+                    self.ax_pri_1.plot(x, y_mod, "k-", linewidth=1.0)
+                    self.ax_pri_2.plot(x, y_exp-y_mod, "k-", linewidth=1.0)
 
+        if x_lim_min is None:
+            return
+        if y_lim_max is None:
+            return
         x_diff = x_lim_max - x_lim_min
         y_diff = y_lim_max - y_lim_min
         y_diff_2 = y_lim_max_2 - y_lim_min_2
