@@ -14,10 +14,17 @@ def w_for_pd_meas(obj, layout_11, layout_12, layout_13, layout_2, layout_3, w_ou
     np_y_su_1 = numpy.array(obj.intensity_up_sigma, dtype = float)
     np_y_d_1 = numpy.array(obj.intensity_down, dtype = float)
     np_y_sd_1 = numpy.array(obj.intensity_down_sigma, dtype = float)
-    np_y_s_1 = np_y_u_1 + np_y_d_1
-    np_y_ss_1 = numpy.sqrt(numpy.square(np_y_su_1) + numpy.square(np_y_sd_1))
-    np_y_m_1 = np_y_u_1 - np_y_d_1
-    np_y_sm_1 = np_y_ss_1
+
+    if numpy.all(numpy.isnan(np_y_u_1)):
+        np_y_s_1 = numpy.array(obj.intensity, dtype = float)
+        np_y_ss_1 = numpy.array(obj.intensity_sigma, dtype = float)
+        np_y_m_1 = 0*np_y_s_1
+        np_y_sm_1 = np_y_ss_1
+    else:
+        np_y_s_1 = np_y_u_1 + np_y_d_1
+        np_y_ss_1 = numpy.sqrt(numpy.square(np_y_su_1) + numpy.square(np_y_sd_1))
+        np_y_m_1 = np_y_u_1 - np_y_d_1
+        np_y_sm_1 = np_y_ss_1
 
     np_xys_1 = numpy.vstack((np_x_1, np_y_s_1, np_y_ss_1)).transpose()
     np_xy_1 = numpy.vstack((np_x_1, np_y_s_1)).transpose()
