@@ -17,12 +17,12 @@ def w_for_pd_proc(obj, layout_11, layout_12, layout_13, layout_2, layout_3, w_ou
     np_y_b_1 = numpy.array(obj.intensity_bkg_calc, dtype = float)
     np_y_u_2 = numpy.array(obj.intensity_up_total, dtype = float)
     np_y_d_2 = numpy.array(obj.intensity_down_total, dtype = float)
-    np_y_s_1 = np_y_u_1 + np_y_d_1
-    np_y_ss_1 = numpy.sqrt(numpy.square(np_y_su_1) + numpy.square(np_y_sd_1))
+    np_y_s_1 = numpy.array(obj.intensity, dtype = float)
+    np_y_ss_1 = numpy.array(obj.intensity_sigma, dtype = float)
     np_y_m_1 = np_y_u_1 - np_y_d_1
     np_y_sm_1 = np_y_ss_1
-    np_y_s_2 = np_y_u_2 + np_y_d_2
-    np_y_m_2 = np_y_u_2 - np_y_d_2
+    np_y_s_2 = numpy.array(obj.intensity_total, dtype = float)
+    np_y_m_2 = numpy.array(obj.intensity_diff_total, dtype = float)
 
     np_xysm_1 = numpy.vstack((np_x_1, np_y_s_1, np_y_ss_1, np_y_s_2)).transpose()
     np_xb_1 = numpy.vstack((np_x_1, 2*np_y_b_1)).transpose()
